# MIT License
#
# Copyright (c) 2024 Jeff Moe
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

""" Read CSV contacts file exported from hubspot."""

import argparse
import csv
import pandas as pd


def parse_args():
    parser = argparse.ArgumentParser(description="Parse Hubspot Contacts CSV Export")

    parser.add_argument(
        "-c",
        "--csv",
        help="Contacts CSV File",
        type=str,
        required=True,
    )

    parser.add_argument(
        "-d",
        "--dump",
        help="Dump CSV contents",
        action="store_true",
    )

    parser.add_argument(
        "-f",
        "--fields",
        help="Fields from CSV header",
        action="store_true",
    )

    args = parser.parse_args()
    return args


def csv_dump(CSV):
    df = pd.read_csv(CSV, low_memory=False, chunksize=1000)
    for chunk in df:
        print(chunk.to_string())


def csv_fields(CSV):
    df = pd.read_csv(CSV, low_memory=False, header=0)
    print("\n".join([col for col in df.columns]))


def main():
    args = parse_args()
    CSV = args.csv

    if args.dump:
        csv_dump(CSV)

    if args.fields:
        csv_fields(CSV)


if __name__ == "__main__":
    main()
